
![AppVeyor](https://img.shields.io/badge/build-success-brightgreen)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/gnnex)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/gnnex)
![PyPI](https://img.shields.io/pypi/v/gnnex)
![GitHub](https://img.shields.io/github/license/ifkid/gnnex)
## Introduction

gnnex is to explain the complex GCN model,
it shows by drawing the most important edges in whole networks.

Absolutely, there are many different  basic GCN models, so you can define your own
model.

By rewriting graph.py to define your own GCN Model and rewriting train.py to train your 
own GCN modeland generate the WEIGHT matrix.

At last, draw the important edges according to WEIGHT matrix above.

## Installed 
>keras==2.3.1

>numpy==1.17.2

>pandas==0.25.3

>matplotlib==3.1.1

>scipy==1.3.2

>networkx==2.2

>seaborn==0.9.0

## Usage

pip install gnnex

## Basic Model

You should define your own model according to your task to be resolved. By rewriting graph.py to define model and rewriting train.py to train your own model. 


